#ifndef __LCD_H
#define __LCD_H
#include "sys.h"
/*#define sce PBout(0)
#define res PBout(1)
#define dc PBout(2)
#define sdin PBout(3)
#define sclk PBout(4)*/
#define sce PBout(5)
#define res PBout(6)
#define dc PBout(7)
#define sdin PBout(8)
#define sclk PBout(9)
void LCD_GPIO_Init(void);
void LCD_WriteByte(u8 dt,u8 command );
void LCD_Init(void);
void LCD_Set_XY(u8 X,u8 Y);
void LCD_Clear(void);
void LCD_Write_Shu(u8 row,u8 page,u8 c);
void LCD_Write_Hanzi(u8 row,u8 page,u8 c);


#endif


