#include "sys.h" 
#include "delay.h"
#include "usart.h"
#include "lcd.h" 
int main()
{
	delay_init();
	LCD_GPIO_Init();
	res=0;
	delay_ms(10);
	res=1;
	LCD_Init();
	LCD_Clear();
	while(1)
	{ 
		LCD_Write_Hanzi(0,0,0);
		LCD_Write_Hanzi(2,0,1);
		LCD_Write_Hanzi(4,0,2);
		LCD_Write_Hanzi(6,0,3);
		LCD_Write_Hanzi(8,0,4);
		LCD_Write_Shu(4,2,8);
		LCD_Write_Shu(5,2,8);
		LCD_Write_Shu(6,2,7);
		LCD_Write_Shu(4,4,5);
		LCD_Write_Shu(5,4,2);
		LCD_Write_Shu(6,4,1);
	}
}
